==> mingw-w64-starpu-1.4.0-2.src.tar.zst: starpu-1.4.0/doc/doxygen_web_faq/html_web_faq/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU FAQs", "index.html", [
    [ "Organization", "index.html#Organization", null ],
    [ "Check List When Performance Are Not There", "CheckListWhenPerformanceAreNotThere.html", [
      [ "Check Task Size", "CheckListWhenPerformanceAreNotThere.html#CheckTaskSize", null ],
      [ "Configuration Which May Improve Performance", "CheckListWhenPerformanceAreNotThere.html#ConfigurationImprovePerformance", null ],
      [ "Data Related Features Which May Improve Performance", "CheckListWhenPerformanceAreNotThere.html#DataRelatedFeaturesToImprovePerformance", null ],
      [ "Task Related Features Which May Improve Performance", "CheckListWhenPerformanceAreNotThere.html#TaskRelatedFeaturesToImprovePerformance", null ],
      [ "Scheduling Related Features Which May Improve Performance", "CheckListWhenPerformanceAreNotThere.html#SchedulingRelatedFeaturesToImprovePerformance", null ],
      [ "CUDA-specific Optimizations", "CheckListWhenPerformanceAreNotThere.html#CUDA-specificOptimizations", null ],
      [ "OpenCL-specific Optimizations", "CheckListWhenPerformanceAreNotThere.html#OpenCL-specificOptimizations", null ],
      [ "Detecting Stuck Conditions", "CheckListWhenPerformanceAreNotThere.html#DetectionStuckConditions", null ],
      [ "How to Limit Memory Used By StarPU And Cache Buffer Allocations", "CheckListWhenPerformanceAreNotThere.html#HowToLimitMemoryPerNode", null ],
      [ "How To Reduce The Memory Footprint Of Internal Data Structures", "CheckListWhenPerformanceAreNotThere.html#HowToReduceTheMemoryFootprintOfInternalDataStructures", null ],
      [ "How To Reuse Memory", "CheckListWhenPerformanceAreNotThere.html#HowtoReuseMemory", null ],
      [ "Performance Model Calibration", "CheckListWhenPerformanceAreNotThere.html#PerformanceModelCalibration", null ],
      [ "Profiling", "CheckListWhenPerformanceAreNotThere.html#Profiling", null ],
      [ "Overhead Profiling", "CheckListWhenPerformanceAreNotThere.html#OverheadProfiling", null ]
    ] ],
    [ "Frequently Asked Questions", "FrequentlyAskedQuestions.html", [
      [ "How To Initialize A Computation Library Once For Each Worker?", "FrequentlyAskedQuestions.html#HowToInitializeAComputationLibraryOnceForEachWorker", null ],
      [ "Hardware Topology", "FrequentlyAskedQuestions.html#HardwareTopology", [
        [ "Interoperability hwloc", "FrequentlyAskedQuestions.html#InteroperabilityHWLOC", null ],
        [ "Memory", "FrequentlyAskedQuestions.html#TopologyMemory", null ],
        [ "Workers", "FrequentlyAskedQuestions.html#TopologyWorkers", null ],
        [ "Bus", "FrequentlyAskedQuestions.html#TopologyBus", null ]
      ] ],
      [ "Using The Driver API", "FrequentlyAskedQuestions.html#UsingTheDriverAPI", null ],
      [ "On-GPU Rendering", "FrequentlyAskedQuestions.html#On-GPURendering", null ],
      [ "Using StarPU With MKL 11 (Intel Composer XE 2013)", "FrequentlyAskedQuestions.html#UsingStarPUWithMKL", null ],
      [ "Thread Binding on NetBSD", "FrequentlyAskedQuestions.html#ThreadBindingOnNetBSD", null ],
      [ "StarPU permanently eats 100% of all CPUs", "FrequentlyAskedQuestions.html#StarPUEatsCPUs", null ],
      [ "Interleaving StarPU and non-StarPU code", "FrequentlyAskedQuestions.html#PauseResume", null ],
      [ "When running with CUDA or OpenCL devices, I am seeing less CPU cores", "FrequentlyAskedQuestions.html#GPUEatingCores", null ],
      [ "StarPU does not see my CUDA device", "FrequentlyAskedQuestions.html#CUDADrivers", null ],
      [ "StarPU does not see my OpenCL device", "FrequentlyAskedQuestions.html#OpenCLDrivers", null ],
      [ "There seems to be errors when copying to and from CUDA devices", "FrequentlyAskedQuestions.html#CUDACopyError", null ],
      [ "I keep getting a \"Incorrect performance model file\" error", "FrequentlyAskedQuestions.html#IncorrectPerformanceModelFile", null ]
    ] ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"CheckListWhenPerformanceAreNotThere.html",
"group__API__CUDA__Extensions.html#ga08ef1dd9623d7adb87cede9e60d3e1dc",
"group__API__Codelet__And__Tasks.html#ga842f80f41741306e78963d5b1cec4b7f",
"group__API__Data__Interfaces.html#ae2a9b938ace8afeb6de759dadb7181a5",
"group__API__Data__Interfaces.html#ga9037815eabc726906d66140b62c03b9b",
"group__API__Data__Management.html#ga358aba7459b7f99a6dbaa189ce57b925",
"group__API__Data__Partition.html#ga8d9bfdd68b278fbb28b7a7208f72a76e",
"group__API__HeteroPrio.html#ga7708e84322a9a8504470127a66b9ca7e",
"group__API__Insert__Task.html#gad666d04cdc314666ed1f6951b1dd0a2a",
"group__API__MPI__Support.html#ga4cd283c401aa59ae226bd1c5da1b295f",
"group__API__Modularized__Scheduler.html#a5c357391adcfaacde9bae236172721d4",
"group__API__OpenCL__Extensions.html#ga84a524eaac758722f083ee129a19a567",
"group__API__OpenMP__Runtime__Support.html#ggacc6078a78820c367f07d37da11c04520a1bd6f1e299e1ecbcda4ba3a515ff24a6",
"group__API__Perf__Monitoring.html#ggab66267d03f0557b14cc3ec0c24c01ebaa9bad219b5a2ca58983751f604b5a5cce",
"group__API__Performance__Model.html#structstarpu__perfmodel__history__list",
"group__API__SC__Hypervisor.html#ga84e68fc3ee959e12c6b5d49b4db7a441",
"group__API__Scheduling__Contexts.html#ga29e7f45270fa484dfa9ff9354dd5ae16",
"group__API__Standard__Memory__Library.html#gaa82c510089966d9e7150d468f1fd4e8f",
"group__API__Toolbox.html#ga47941f066680d14c0ba6e47484219742",
"group__API__Workers__Properties.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a0f41ef0eff3429abe8480b285c8e37d9",
"interfacefstarpu__mod_1_1fstarpu__data__wont__use.html",
"interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html",
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__task__post__build.html",
"starpu__config_8h.html#a73bd4a8c717e77976895646bc474ca29",
"starpu__util_8h.html#aa0c1167bb311135eecf24a0e7c885b7f"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> mingw-w64-starpu-1.4.2-1.src.tar.zst: starpu-1.4.2/doc/doxygen_web_faq/html_web_faq/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU FAQs", "index.html", [
    [ "Check List When Performance Are Not There", "CheckListWhenPerformanceAreNotThere.html", [
      [ "Check Task Size", "CheckListWhenPerformanceAreNotThere.html#CheckTaskSize", null ],
      [ "Configuration Which May Improve Performance", "CheckListWhenPerformanceAreNotThere.html#ConfigurationImprovePerformance", null ],
      [ "Data Related Features Which May Improve Performance", "CheckListWhenPerformanceAreNotThere.html#DataRelatedFeaturesToImprovePerformance", null ],
      [ "Task Related Features Which May Improve Performance", "CheckListWhenPerformanceAreNotThere.html#TaskRelatedFeaturesToImprovePerformance", null ],
      [ "Scheduling Related Features Which May Improve Performance", "CheckListWhenPerformanceAreNotThere.html#SchedulingRelatedFeaturesToImprovePerformance", null ],
      [ "CUDA-specific Optimizations", "CheckListWhenPerformanceAreNotThere.html#CUDA-specificOptimizations", null ],
      [ "OpenCL-specific Optimizations", "CheckListWhenPerformanceAreNotThere.html#OpenCL-specificOptimizations", null ],
      [ "Detecting Stuck Conditions", "CheckListWhenPerformanceAreNotThere.html#DetectionStuckConditions", null ],
      [ "How to Limit Memory Used By StarPU And Cache Buffer Allocations", "CheckListWhenPerformanceAreNotThere.html#HowToLimitMemoryPerNode", null ],
      [ "How To Reduce The Memory Footprint Of Internal Data Structures", "CheckListWhenPerformanceAreNotThere.html#HowToReduceTheMemoryFootprintOfInternalDataStructures", null ],
      [ "How To Reuse Memory", "CheckListWhenPerformanceAreNotThere.html#HowtoReuseMemory", null ],
      [ "Performance Model Calibration", "CheckListWhenPerformanceAreNotThere.html#PerformanceModelCalibration", null ],
      [ "Profiling", "CheckListWhenPerformanceAreNotThere.html#Profiling", null ],
      [ "Overhead Profiling", "CheckListWhenPerformanceAreNotThere.html#OverheadProfiling", null ]
    ] ],
    [ "Frequently Asked Questions", "FrequentlyAskedQuestions.html", [
      [ "How To Initialize A Computation Library Once For Each Worker?", "FrequentlyAskedQuestions.html#HowToInitializeAComputationLibraryOnceForEachWorker", null ],
      [ "Hardware Topology", "FrequentlyAskedQuestions.html#HardwareTopology", [
        [ "Interoperability hwloc", "FrequentlyAskedQuestions.html#InteroperabilityHWLOC", null ],
        [ "Memory", "FrequentlyAskedQuestions.html#TopologyMemory", null ],
        [ "Workers", "FrequentlyAskedQuestions.html#TopologyWorkers", null ],
        [ "Bus", "FrequentlyAskedQuestions.html#TopologyBus", null ]
      ] ],
      [ "Using The Driver API", "FrequentlyAskedQuestions.html#UsingTheDriverAPI", null ],
      [ "On-GPU Rendering", "FrequentlyAskedQuestions.html#On-GPURendering", null ],
      [ "Using StarPU With MKL 11 (Intel Composer XE 2013)", "FrequentlyAskedQuestions.html#UsingStarPUWithMKL", null ],
      [ "Thread Binding on NetBSD", "FrequentlyAskedQuestions.html#ThreadBindingOnNetBSD", null ],
      [ "StarPU permanently eats 100% of all CPUs", "FrequentlyAskedQuestions.html#StarPUEatsCPUs", null ],
      [ "Interleaving StarPU and non-StarPU code", "FrequentlyAskedQuestions.html#PauseResume", null ],
      [ "When running with CUDA or OpenCL devices, I am seeing less CPU cores", "FrequentlyAskedQuestions.html#GPUEatingCores", null ],
      [ "StarPU does not see my CUDA device", "FrequentlyAskedQuestions.html#CUDADrivers", null ],
      [ "StarPU does not see my OpenCL device", "FrequentlyAskedQuestions.html#OpenCLDrivers", null ],
      [ "There seems to be errors when copying to and from CUDA devices", "FrequentlyAskedQuestions.html#CUDACopyError", null ],
      [ "I keep getting a \"Incorrect performance model file\" error", "FrequentlyAskedQuestions.html#IncorrectPerformanceModelFile", null ]
    ] ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"CheckListWhenPerformanceAreNotThere.html",
"group__API__Codelet__And__Tasks.html#adac9af88fed23241fc65259712352126",
"group__API__Data__Interfaces.html#ae1d888af673475dbcf85104b6c359a6e",
"group__API__Data__Interfaces.html#structstarpu__variable__interface",
"group__API__HeteroPrio.html#ga08616241ba1e2b52a418b7de4c03895a",
"group__API__MPI__Support.html#ga2c49e782fd50113aa0ce10a5168ab57f",
"group__API__OpenCL__Extensions.html#ga1b591248c13dc33e2e9b00ace593405e",
"group__API__Perf__Monitoring.html#ga4ef027a8fd9b4716e7ecd177457af6ae",
"group__API__Running__Drivers.html#gac8f8848b64980676190d77d265fda841",
"group__API__Scheduling__Policy.html#gab389801ed30db46c5620b3e0c0d6abd9",
"group__API__Workers.html#gacb9d262c066c047ae55f691adc876db3",
"interfacefstarpu__mod_1_1fstarpu__data__unpartition.html",
"interfacefstarpu__mod_1_1fstarpu__task__create__sync.html",
"sc__hypervisor__monitoring_8h.html#a4c01108a62fd573f2a6430381ce7943f"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
